# ecn_robotics v0.0.3

This python package aims to provide some utility function for robot analysis.

By [Meltwin](https://github.com/Meltwin) for [Centrale Nantes Robotics](https://github.com/CentraleNantesRobotics) - 2023

## Modules

- **Display** : Provide some print utilities for matrix, headers, choices, ...
- **Math** : Provide lacking function for analysis

For a detailed description of each function, please refer to the [wiki](https://github.com/Baxterminator/ecn_robotics/wiki)

## Installation

### PiPy Repository (Recommended)

This package is available on the PiPy repository. So you can use the pip manager with the following command:

```shell
pip install ecn_robotics
```

### Manual use

Another way of using this directory is to drag the ecn_robotics directory in this repository in the root of your program.

## Dependencies
 
| Package  | Link                               |
|:--------:|:-----------------------------------|
|  Numpy   | https://numpy.org/                 |
| Colorama | https://pypi.org/project/colorama/ |

